import { Graph, Shape } from '@antv/x6'
export function useGraph({ container }) {
  const graph = new Graph({
    container,
    panning: true,
    grid: {
      visible: true,
      type: 'doubleMesh',
      args: [
        {
          color: '#ECECEC', // 主网格线颜色
          thickness: 1, // 主网格线宽度
        },
        {
          color: '#ECECEC', // 次网格线颜色
          thickness: 1, // 次网格线宽度
          factor: 1, // 主次网格线间隔
        },
      ],
    },
    mousewheel: {
      enabled: true,
      zoomAtMousePosition: true,
      modifiers: 'ctrl',
      minScale: 0.5,
      maxScale: 3,
    },
    connecting: {
      router: 'manhattan',
      connector: {
        name: 'rounded',
        args: {
          radius: 8,
        },
      },
      anchor: 'center',
      connectionPoint: 'anchor',
      allowBlank: false,
      snap: {
        radius: 20,
      },
      createEdge() {
        return new Shape.Edge({
          attrs: {
            line: {
              stroke: '#A1A7B0',
              strokeWidth: 1,
              targetMarker: {
                name: 'block',
                width: 10,
                height: 6,
              },
            },
          },
          zIndex: 0,
        })
      },
      validateConnection({ targetMagnet }) {
        return !!targetMagnet
      },
    },
    highlighting: {
      magnetAdsorbed: {
        name: 'stroke',
        args: {
          attrs: {
            fill: '#5F95FF',
            stroke: '#5F95FF',
          },
        },
      },
    },
  })
  return graph
}
